@@ -244,8 +244,8 @@ browser()
 hessian <- function (obj, ...)  UseMethod("hessian")
 
 
-hessian.default <- function(func, x, func.args=NULL, d=0.01, eps=1e-4,r=6)
-{  D <- genD.default(func,x,func.args=func.args, d=d, eps=eps, r=r)$D
+hessian.default <- function(obj, x, obj.args=NULL, d=0.01, eps=1e-4, r=6)
+{  D <- genD.default(obj, x, obj.args=obj.args, d=d, eps=eps, r=r)$D
    H <- diag(0,length(x))
    u <- 0
    for(i in 1:length(x))
@@ -360,7 +360,8 @@ span.v0 <- function(func, x,d=0.01, eps=1e-4,r=6, show.details=F){
 
 span <- function (obj, ...)  UseMethod("span")
 
-span.default <- function(func, x, func.args=NULL, d=0.01, eps=1e-4,r=6, show.details=F)
+span.default <- function(obj, x, obj.args=NULL, d=0.01, eps=1e-4, r=6,
+      show.details=F)
 {
 #   performs a svd of the tangent vectors at the point x. This can be used
 #   to calculate the dimension of the tangent space (ie. by over specifying 
@@ -372,10 +373,10 @@ span.default <- function(func, x, func.args=NULL, d=0.01, eps=1e-4,r=6, show.det
 #      approximation of the tangent vectors to the parameter 
 #      manifold. SVD is then used to calculate their span.     
 #
-#  func     a charater string of the name of a function which returns the
+#  obj     a function which returns the
 #                residual vector for a given parameter vector.
-#   x       The parameters of func with respect to which derivative is calculated.
-#  func.args A list of any other arguments to the function
+#   x       The parameters of obj with respect to which derivative is calculated.
+#  obj.args A list of any other arguments to the function
 #
 #   d       initial interval value by
 #               default set to 0.01*x or eps if x is 0.0 .
@@ -386,15 +387,15 @@ span.default <- function(func, x, func.args=NULL, d=0.01, eps=1e-4,r=6, show.det
 
   v <- 2
   p <- length(x)     #  number of parameters (= dim of M if not over parameterized.
-  n <- length(do.call("func",append(list(x), func.args)))  #dimension of sample space.
+  n <- length(do.call("obj",append(list(x), obj.args)))  #dimension of sample space.
   D <- array(1, c(n, p, r)) 
   h <- abs(d*x)+eps*(x==0.0)
   for(k in 1:r)  # successively reduce h 
     {if(show.details) cat("\n k=",k, " p: ")
      for(i in 1:p)  # each parameter  - first deriv.
       {if(show.details) cat(" ",i)
-       D[,i,k]<-(do.call("func",append(list(x+(i==(1:p))*h), func.args)) -
-                 do.call("func",append(list(x-(i==(1:p))*h), func.args)))/(2*h[i])
+       D[,i,k]<-(do.call("obj",append(list(x+(i==(1:p))*h), obj.args)) -
+                 do.call("obj",append(list(x-(i==(1:p))*h), obj.args)))/(2*h[i])
        NULL 
       }
      h <- h/v     # Reduced h by 1/v.
@@ -433,17 +434,19 @@ curvature <- function (obj, ...)
 }
 
 
-curvature.default <- function(func, x, func.args=NULL, d=0.01, eps=1e-4,r=6,
+curvature.default <- function(obj, x, obj.args=NULL, d=0.01, eps=1e-4,r=6,
       signif=0.05, show.details=F, warn=T)
-{curvature(genD.default(func,x, func.args=func.args, d=d, eps=eps,r=r),
+{# obj is a function
+ curvature(genD.default(obj,x, obj.args=obj.args, d=d, eps=eps,r=r),
      signif=0.05, show.details=F, warn=warn)
 }
 
 
-curvature.Darray <- function(Dlist, signif = 0.05, show.extra.details=F, show.details=show.extra.details, warn=T)
+curvature.Darray <- function(obj, signif = 0.05,
+   show.extra.details=F, show.details=show.extra.details, warn=T)
 {
 # Curvature summary statistics as in Bates and Watts.
-#  Dlist is a list as generated by genD.default and genD.TSestModel,
+#  obj is a list as generated by genD.default and genD.TSestModel,
 #       with the 3 elements as follows:
 #   $D is a matrix of first(gradients) and second order partial
 #      derivatives organized in the same manner as Bates and 
@@ -462,23 +465,23 @@ curvature.Darray <- function(Dlist, signif = 0.05, show.extra.details=F, show.de
 #   modified substantially by Paul Gilbert (May, 1992 and Dec, 1996)
 #    from original code by Xingqiao Liu,   May, 1991.
 #
-   if (all(Dlist$D==0))
+   if (all(obj$D==0))
      stop("The array of first and second order derivatives is all zeros.")
 
-   p <- Dlist$p
-   n <- dim(Dlist$D)[1]   # dimesion of sample space
+   p <- obj$p
+   n <- dim(obj$D)[1]   # dimesion of sample space
    pp <- p*(p+1)/2 # p' max number of independent col in the acceleration array.
    m <- p * (p + 3)/2  # m= p+pp is second dimension of D. It is also the max 
                        # span of the combined tangent and accelation spaces.
-   if (m!=dim(Dlist$D)[2]) stop("Dimesion of D matrix is not consistent with p")
-   residual <- c(Dlist$f0)   # c() in case it is a column vector
+   if (m!=dim(obj$D)[2]) stop("Dimesion of D matrix is not consistent with p")
+   residual <- c(obj$f0)   # c() in case it is a column vector
    s.sqr <- sum(residual^2)/(length(residual)-2)
    if(show.extra.details) cat("p=",p," pp=",pp," m=",m, " n=",n,"\n")
  
 #  Form QR decomposition of D and produce matrix Q and R.
 #
 
-   QRofD <- qr(Dlist$D) 
+   QRofD <- qr(obj$D) 
 
 # Now calculate R, which is D rotated onto an othogonal basis with the 
 # tangent space first, then acceleration space. 
@@ -487,14 +490,14 @@ curvature.Darray <- function(Dlist, signif = 0.05, show.extra.details=F, show.de
 # all zeros  and so those rows are truncated from R.
 
 #   Q <- qr.qy(QRofD, diag(1,n)) [,1:m]
-#   R <- t(Q) %*% Dlist$D   this is the same as
+#   R <- t(Q) %*% obj$D   this is the same as
 #  R[1:m,]could be used to truncate but it is possible for m to exceed dim(D)[1]
-   R <- qr.qty(QRofD, Dlist$D )  
+   R <- qr.qty(QRofD, obj$D )  
 
    if(show.extra.details) 
         {cat( "Matrix D, tangent and acceleration vectors in columns ")
          cat("organized as in Bates and Watts p235, 236\n")
-         print(Dlist$D)
+         print(obj$D)
          cat("Residual Vector\n"); print(residual)
 	 cat("Matrix Q from QR decomposition of D\n")
          print( qr.qy(QRofD, diag(n)))
@@ -536,7 +539,7 @@ curvature.Darray <- function(Dlist, signif = 0.05, show.extra.details=F, show.de
    dimnames(result)<-list(NULL,c("Parms","Sample","Sign. level","RMS Parameter",
          "RMS Intrinsic","c*sqrt(F) Parameter","c*sqrt(F) Intrinsic",
          "Min Axis Ratio","Max Axis Ratio")) 
-   classed(list(stats=result, Dlist=Dlist, C=C), "curvature")# curvature.Darray constructor
+   classed(list(stats=result, Dlist=obj, C=C), "curvature")# curvature.Darray constructor
 }
 
 print.curvatureArray <- function(x, ...)
@@ -713,11 +716,11 @@ C
 #   as an arguement (and call it multiple times).  
 #######################################################################
 
-genD <- function(arg,...)UseMethod("genD")
+genD <- function(obj, ...)UseMethod("genD")
 
-genD.default <- function(func, x, d=0.01, eps=1e-4, r=6, func.args=NULL){
+genD.default <- function(obj, x, d=0.01, eps=1e-4, r=6, obj.args=NULL){
 # This function calculates a numerical approximation of the first and second
-#   derivatives (gradient and hessian) of func at the point x. The calculation
+#   derivatives (gradient and hessian) of obj at the point x. The calculation
 #   is done by Richardson's extrapolation (see eg. G.R.Linfield and J.E.T.Penny
 #   "Microcomputers in Numerical Analysis"). The method should be used when
 #   accuracy, as opposed to speed, is important.
@@ -729,15 +732,15 @@ genD.default <- function(func, x, d=0.01, eps=1e-4, r=6, func.args=NULL){
 #   $p is the dimension of the parameter space=dim of the tangent space.
 #   $f0 is the function value at the point where the matrix D 
 #        was calculated. 
-#   Also the arguments (func, x, d, eps, r) are returned
+#   Also the arguments (obj, x, d, eps, r) are returned
 #
 #   modified substantially by Paul Gilbert (May, 1992)
 #    from original code by Xingqiao Liu,   May, 1991.
 #
 
-#  func    the function. The first arg to func must be a vector.
+#  obj    the function. The first arg to obj must be a vector.
 #  x       the parameter vector.
-#  func.args any additional arguments to func.
+#  obj.args any additional arguments to the function obj.
 #  d       gives the fraction of x to use for the initial numerical approximation.
 #  eps     is used for zero elements of x.
 #  r       the number of Richardson improvement iterations.
@@ -765,10 +768,10 @@ genD.default <- function(func, x, d=0.01, eps=1e-4, r=6, func.args=NULL){
 #    improve the accuracy of the computation.
 
    v <-2
-   zt <- .001     #Rbug unix.time has trouble finding func
-   # f0 <- func(x)
-   f0 <- do.call("func",append(list(x), func.args))
- # zt <-unix.time(f0 <- func(x))   #  f0 is the value of the function at x.
+   zt <- .001     #Rbug unix.time has trouble finding obj
+   # f0 <- obj(x)
+   f0 <- do.call("obj",append(list(x), obj.args))
+ # zt <-unix.time(f0 <- obj(x))   #  f0 is the value of the function at x.
                    # (Real value or point in sample space ie- residual vector)	
    p <- length(x)  #  number of parameters (theta)
    zt <- zt[1] *r*2*(p*(p + 3))/2
@@ -786,10 +789,10 @@ genD.default <- function(func, x, d=0.01, eps=1e-4, r=6, func.args=NULL){
    for(i in 1:p)    # each parameter  - first deriv. & hessian diagonal
         {h <-h0
          for(k in 1:r)  # successively reduce h 
-           {#f1 <- func(x+(i==(1:p))*h)
-            #f2 <- func(x-(i==(1:p))*h) 
-            f1 <- do.call("func",append(list(x+(i==(1:p))*h), func.args))
-            f2 <- do.call("func",append(list(x-(i==(1:p))*h), func.args))
+           {#f1 <- obj(x+(i==(1:p))*h)
+            #f2 <- obj(x-(i==(1:p))*h) 
+            f1 <- do.call("obj",append(list(x+(i==(1:p))*h), obj.args))
+            f2 <- do.call("obj",append(list(x-(i==(1:p))*h), obj.args))
             Daprox[,k] <- (f1 - f2)  / (2*h[i])    # F'(i) 
             Haprox[,k] <- (f1-2*f0+f2)/ h[i]^2     # F''(i,i) hessian diagonal
             h <- h/v     # Reduced h by 1/v.
@@ -814,12 +817,12 @@ genD.default <- function(func, x, d=0.01, eps=1e-4, r=6, func.args=NULL){
             else 
              {h <-h0
               for(k in 1:r)  # successively reduce h 
-                {#f1 <- func(x+(i==(1:p))*h + (j==(1:p))*h)
-                 #f2 <- func(x-(i==(1:p))*h - (j==(1:p))*h)
-                 f1 <- do.call("func", append(
-                        list(x+(i==(1:p))*h + (j==(1:p))*h), func.args))
-                 f2 <- do.call("func",append(
-                        list(x-(i==(1:p))*h - (j==(1:p))*h), func.args))  
+                {#f1 <- obj(x+(i==(1:p))*h + (j==(1:p))*h)
+                 #f2 <- obj(x-(i==(1:p))*h - (j==(1:p))*h)
+                 f1 <- do.call("obj", append(
+                        list(x+(i==(1:p))*h + (j==(1:p))*h), obj.args))
+                 f2 <- do.call("obj",append(
+                        list(x-(i==(1:p))*h - (j==(1:p))*h), obj.args))  
                  Daprox[,k]<- (f1 - 2*f0 + f2 -
                                   Hdiag[,i]*h[i]^2 - 
                                   Hdiag[,j]*h[j]^2)/(2*h[i]*h[j])  # F''(i,j)  
@@ -834,10 +837,10 @@ genD.default <- function(func, x, d=0.01, eps=1e-4, r=6, func.args=NULL){
           }  
        }
 invisible(classed(list(D=D,  # Darray constructor (genD.default)
-             p=length(x),f0=f0,func=func, x=x, d=d, eps=eps, r=r), "Darray"))
+             p=length(x),f0=f0,func=obj, x=x, d=d, eps=eps, r=r), "Darray"))
 }
 
-genD.default.v2 <- function(func, x, func.args=NULL, d=0.01, eps=1e-4, r=6){
+genD.default.v2 <- function(func, x, obj.args=NULL, d=0.01, eps=1e-4, r=6){
 # This function calculates a numerical approximation of the first and second
 #   derivatives (gradient and hessian) of func at the point x. The calculation
 #   is done by Richardson's extrapolation (see eg. G.R.Linfield and J.E.T.Penny
@@ -884,7 +887,7 @@ genD.default.v2 <- function(func, x, func.args=NULL, d=0.01, eps=1e-4, r=6){
 #    improve the accuracy of the computation.
 
    v <-2
-   f0 <- do.call("func", append(list(x), func.args))  #  f0 is the value of the function at x.
+   f0 <- do.call("func", append(list(x), obj.args))  #  f0 is the value of the function at x.
    p <- length(x)  #  number of parameters (theta)
    h0 <- abs(d*x)+eps*(x==0.0)
    D <- matrix(0, length(f0),(p*(p + 3))/2)
@@ -897,8 +900,8 @@ genD.default.v2 <- function(func, x, func.args=NULL, d=0.01, eps=1e-4, r=6){
    for(i in 1:p)    # each parameter  - first deriv. & hessian diagonal
         {h <-h0
          for(k in 1:r)  # successively reduce h 
-           {f1 <- do.call("func", append(list(x+(i==(1:p))*h), func.args))
-            f2 <- do.call("func", append(list(x-(i==(1:p))*h), func.args))
+           {f1 <- do.call("func", append(list(x+(i==(1:p))*h), obj.args))
+            f2 <- do.call("func", append(list(x-(i==(1:p))*h), obj.args))
             Daprox[,k] <- (f1 - f2)  / (2*h[i])    # F'(i) 
             Haprox[,k] <- (f1-2*f0+f2)/ h[i]^2     # F''(i,i) hessian diagonal
             h <- h/v     # Reduced h by 1/v.
@@ -920,8 +923,8 @@ genD.default.v2 <- function(func, x, func.args=NULL, d=0.01, eps=1e-4, r=6){
             else 
              {h <-h0
               for(k in 1:r)  # successively reduce h 
-                {f1 <- do.call("func", append(list(x+(i==(1:p))*h + (j==(1:p))*h), func.args))
-                 f2 <- do.call("func", append(list(x-(i==(1:p))*h - (j==(1:p))*h), func.args))  
+                {f1 <- do.call("func", append(list(x+(i==(1:p))*h + (j==(1:p))*h), obj.args))
+                 f2 <- do.call("func", append(list(x-(i==(1:p))*h - (j==(1:p))*h), obj.args))  
                  Daprox[,k]<-(f1-2*f0+f2-Hdiag[,i]*h[i]^2-Hdiag[,j]*h[j]^2)/(2*h[i]*h[j])  # F''(i,j)  
                  h <- h/v     # Reduced h by 1/v.
                 }
