@@ -45,7 +45,7 @@ test.rng <- list(kind="Wichmann-Hill",seed=c(979,1479,1542),normal.kind="Box-Mul
         
   curvatureVAR.def <- curvature.default(function(parms,Shape,data)
    {c(l(set.arrays(Shape,parms=parms),data,result="pred") - output.data(data))}, parms(VARmodel), 
-                  func.args=list(Shape=TSmodel(VARmodel),data=TSdata(VARmodel)),
+                  obj.args=list(Shape=TSmodel(VARmodel),data=TSdata(VARmodel)),
                      d=0.01, eps=1e-4,r=6, show.details=F)$stats
 
 
