@@ -11,13 +11,13 @@
 	# the next 2 lines remove old versions of PADI in the search path
  	invisible(if(0!=length(grep("b*/PADI/.Data",search())))
                          detach(grep("b*/PADI/.Data",search()))  )
-	attach(paste(getenv("PADI"),"/.Data", sep=""), pos=2)
+	attach(paste(Sys.getenv("PADI"),"/.Data", sep=""), pos=2)
 	#load.padi(from=".")    # this gets the version in pwd
 	load.padi()           # this gets the version indicated by PADI
 	# load.padi does the following two dynamic loads 
 	#dyn.load.shared("/usr/lib/libnsl.so")     # splus 3.3 on SunOS5
 	# If the shared library is not loaded then the next has missing symbols
-	#dyn.load(paste(getenv("PADI"),"/lib/splusclnt.o", sep=""))
+	#dyn.load(paste(Sys.getenv("PADI"),"/lib/splusclnt.o", sep=""))
 	search()
    }
 
